% EventBasedEstimatorParameters.m
%
% Load the parameters for the event-based state estimator design of Sec. 
% III-B (Balancing Cube example).
%
% The script loads the matrices of the state space model of the Balancing 
% Cube and defines the parameters for the event-based state estimator.
% 
% For details on the experimental system, refer to reference [7] in the
% paper.  For details on the design of the event-based estimator, refer for
% to reference [6] in the paper.
%
%
% --
% Supplementary material to
%
% S. Trimpe, R. D'Andrea, "Event-Based State Estimation with Variance-Based 
% Triggering", IEEE Transactions on Automatic Control, Special Issue on 
% Control of Cyber-Physical Systems.
%
% Copyright:
% Sebastian Trimpe
% Max Planck Institute for Intelligent Systems
% strimpe(at)tuebingen.mpg.de
% March 2014
%

% Revision history
% [Dec 12, ST]   first version
% [10.03.14, ST] adapt to revised version of the paper


%% Load model data.
% Load Balancing Cube model data (A,C).
load('CubeModel.mat');

% number of states
n = size(A,1);

% number of measurements
M = size(C,1);


%% Event-based state estimator parameters.
% Process and measurement noise variances.
Q = diag([1, 1, 1, 1, 1, 1, 0.01, 1]); 
R = diag([0.1 1 0.1 1 0.1 1 0.1 1 0.1 1 0.1 1]);

% Communication parameters \delta_j
delta = 48*[1 0 1 0 1 0 1 0 1 0 1 0] ...    
    + 4*[0 1 0 1 0 1 0 1 0 1 0 1];          


%% Compute the solution to the DARE
% Solve the discrete-time algebraic Riccati equation (DARE).
P_bar = dare(A',C',Q,R);
